#
# spec file for package libfprint
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Mariusz Fik <fisiu@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?_udevrulesdir: %global _udevrulesdir %(pkg-config --variable=udevdir udev)/rules.d}

Name:           libfprint
Version:        0.6.0
Release:        lp150.51.5
Summary:        Library for fingerprint reader support
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            http://www.freedesktop.org/wiki/Software/fprint
Source0:        http://freedesktop.org/~hadess/%{name}-%{version}.tar.xz
Patch17:        libfprint-upeke2_6stage.diff
Patch21:        libfprint-install_examples.patch
Source99:       baselibs.conf
BuildRequires:  automake
BuildRequires:  gcc-c++
# Needed for patch21
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(nss)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(udev)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(pre):  %fillup_prereq

%description
The fprint project aims to plug a gap in the Linux desktop: support for
consumer fingerprint reader devices.

%package -n libfprint0
Summary:        Library for fingerprint reader support
Group:          Development/Libraries/C and C++
Provides:       %{name} = %{version}

%description -n libfprint0
The fprint project aims to plug a gap in the Linux desktop: support for
consumer fingerprint reader devices.

%package devel
Summary:        Library for fingerprint reader support (developer files)
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       glibc-devel
Requires:       libfprint0 = %{version}

%description devel
This package contains the header files, static libraries and
development documentation for libfprint. If you like to develop
programs using libfprint, you will need to install this package.

%package examples
Summary:        Library for fingerprint reader support (example programs)
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description examples
This package contains the header files, static libraries and
development documentation for libfprint. If you like to develop
programs using libfprint, you will need to install this package.

%prep
%setup -q
%patch17
%patch21

%build
# Needed for patches
autoreconf -fi
%configure \
    --enable-static=no \
    --mandir=%{_mandir} \
    --with-udev-rules-dir=%{_udevrulesdir}

make %{?smp_flags}
make %{?smp_flags} -C examples

%install
make DESTDIR=%{buildroot} install
make DESTDIR=%{buildroot} -C examples install

# Fix file conflict
for f in enroll img_capture verify verify_live; do
    mv %{buildroot}%{_bindir}/$f %{buildroot}%{_bindir}/fprint_$f
done

#remove unpackaged files
rm -f %{buildroot}%{_libdir}/*.la

%post -n libfprint0
/sbin/ldconfig
%{?udev_rules_update:%udev_rules_update}

%postun -n libfprint0 -p /sbin/ldconfig

%files -n libfprint0
%defattr(-, root, root)
%{_libdir}/%{name}.so.*
%{_udevrulesdir}/60-fprint-autosuspend.rules

%files devel
%defattr(-, root, root)
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/fprint.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%files examples
%defattr(-, root, root)
%{_bindir}/fprint_enroll
%{_bindir}/fprint_img_capture
%{_bindir}/fprint_verify
%{_bindir}/fprint_verify_live

%changelog
* Sat Feb  7 2015 p.drouand@gmail.com
- Update to version 0.6.0
  * Drivers:
  - Reduce duplication between AES3500 and AES4000 drivers and
    add support for AES3500 device
  - Add support for UPEK 147e:2020 and Upek Eikon 2 devices
  - Add EgisTec ES603 driver
  - Add VFS5011 driver
  - Always perform 5 scans for image enrollment
  - Better verification with AES1660 driver
  - Better verification for a number of AES drivers
  * Library:
  - Always use Pixman for image manipulation, gdk-pixbuf and ImageMagick
    are not supported any more.
  * Udev rules:
  - Fix warning when USB hub or system does not support power management
- Add pkgconfig(pixman-1) build require; new upstream dependency
- Remove pkgconfig(gdk-pixbuf-2.0) build require; not needed anymore
* Sun Nov 24 2013 crrodriguez@opensuse.org
-  define _udevrulesdir only if not already in place.
- run %%udev_rules_update if such macro is defined
* Sat Sep 21 2013 mailaender@opensuse.org
- Update to version 0.5.1:
  + Add support for 147e:2020 to upeke2 driver
  + Fix possible race condition, and cancellation in uru4000 driver
  + Add Microsoft keyboard to the suspend blacklist
  + Plenty of build fixes
- Adhere to https://en.opensuse.org/SourceUrls
- Rebased libfprint-install_examples.patch
- Removed libfprint-upeke2_add_147e_2020_id_support.patch as it is included now.
* Mon May 20 2013 suse@bugs.jan.ritzerfeld.org
- upeke2: Add support for 147e:2020 ID (fdo#59320)
* Wed Apr 17 2013 idonmez@suse.com
- Fix file conflicts
* Sun Apr 14 2013 crrodriguez@opensuse.org
- fix -devel package requires,nowhere this library requires
  pkgconfig(ImageMagick), pkgconfig(glib-2.0), pkgconfig(libusb-1.0)
  pkgconfig(openssl), pkgconfig(zlib), not at linking time, not at
  the headers..
* Thu Apr 11 2013 crrodriguez@opensuse.org
- Place udev rules in the correct directory.
* Mon Apr  1 2013 fisiu@opensuse.org
- Update to version 0.5.0:
  + Drivers:
  - New VFS300/VFS301 driver
  - New AES2550/AES2810 drivers
  - New AES1660 driver
  - New AES2660 driver
  - New DigitalPersona URU4500 driver
  - Avoid empty capture and improve image contrast in the
    AES2501 and AES2550 drivers
  - Update upektc driver, add support for Eikon Touch 300
  - Fix UrU4000 image capture on ARM
  + Library:
  - Fix global variable collisions with libusb and other system
    headers
  - Fix possible crash in NBIS image processing with some
    fingerprints
  + Udev rules:
  - Fix power control path for newer kernels
  - Move udev rules to the correct directory
  - Don't print duplicated udev rules
  - Include udev rules in the tarball
  - Allow disabling of udev rules for cross-compiling
  - Add driver names in the generated rules
* Wed Sep  5 2012 p.drouand@gmail.com
- Release 0.4.0 :
  * Add support for Validity VFS101 (USB ID 138a:0001)
  * Fix crasher when resizing a fingerprint image
  * Fix wrong timeout being returned when either of
  libusb or libfprint doesn't have a timeout
- Remove unnecessary "obsoletes" and "provides" libfprint0 package entries
- Fix URL
* Mon Aug 27 2012 cfarrell@suse.com
- license update: LGPL-2.1+
  No LGPL-2.1 "only" licenses found in the package
* Sun May 20 2012 zaitor@opensuse.org
- Add libtool as buildrequires.
- Run autoreconf -fi before ./configure due to
  libfprint-install_examples.patch, fixes build on factory.
- Listing files in subpackage examples explicitly so we don't loose
  any on future upgrades.
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Fri Sep 16 2011 andrea.turrini@gmail.com
- fix typos in description
* Thu Nov 11 2010 coolo@novell.com
- own parent directories of udev rules
* Thu Oct  7 2010 fcrozat@novell.com
- Release 0.3.0 (since 0.1.0-pre2):
  * Add support for UPEK TCS4C (USB ID 147e:1000)
  * Use NSS instead of OpenSSL for GPL compliance
  * upeksonly driver bug fixes
  * Fix a crash if a scan was shorter than 8 lines
  * Fix compilation with C++ compiler
  * Add gdk-pixbuf support for image manipulation
  * Add udev rules to allow devices to autosuspend
  * Finish port of AES1610 driver
  * Add UPEK EikonII (TCRD4C) driver
- update libfprint-install_examples.patch
- do not package .la files
* Wed Sep 29 2010 ro@suse.de
- install examples correctly
* Mon Aug  9 2010 ro@suse.de
- add examples subpackage
* Thu Aug  5 2010 ro@suse.de
- work to support 147e:2016 (Upek Eikon 2 as in T410)
- update to 0.1.0-pre2
- add fedora patches
- add patches from brc#504399
- fix udev rule install
- fix enroll_retcode to accept 0x2e as well in upekts and upeke2
- my scanner needs full 5 passes, so set nr_enroll_stages to 6
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Tue May 12 2009 thoenig@suse.de
- run autoreconf -fi before ./configure
* Tue Jan 27 2009 thoenig@suse.de
- add libfprint-deinit-01.patch: Add new function fp_dev_reset used
  to settle the USB device if it was driven into a undefined state.
  (bnc#463557)
* Wed Nov  5 2008 thoenig@suse.de
- move supplementing USB IDs from libfprint0 to pam_fp (bnc#441754)
* Tue Oct 28 2008 thoenig@suse.de
- libfprint0 provide/obsoletes libthinkfinger
* Thu Oct 23 2008 thoenig@suse.de
- generate HAL fdi so that fingerprint readers are properly
  recognized (bnc#438187)
* Mon Oct 13 2008 thoenig@suse.de
- move 'supplements' and 'recommends' to libfprint0
* Thu Oct  9 2008 thoenig@suse.de
- use uppercase for hexadecimal numbers in USB vendor and product
  IDs
* Mon Oct  6 2008 thoenig@suse.de
- add supplements for supported USB devices
- add baselibs.conf (libfprint0) as pam_fp requires libfprint
- fix header for inclusions in C++
* Fri Sep  5 2008 thoenig@suse.de
- initial check-in
